@@ -6,7 +6,7 @@
 # http://www.popbill.com
 # Author : Jeong Yohan (code@linkhub.co.kr)
 # Written : 2015-03-20
-# Updated : 2020-07-27
+# Updated : 2021-12-22
 # Thanks for your interest.
 from .base import PopbillBase, PopbillException, File
 
@@ -489,6 +489,19 @@ class StatementService(PopbillBase):
 
         return self._httpget('/Statement/' + str(ItemCode) + '/' + MgtKey + '/Logs', CorpNum)
 
+    def getSealURL(self, CorpNum, UserID):
+        """ 팝빌 인감 및 첨부문서 등록 URL
+            args
+                CorpNum : 회원 사업자번호
+                UserID  : 회원 팝빌아이디
+            return
+                30초 보안 토큰을 포함한 url
+            raise
+                PopbillException
+        """
+        result = self._httpget('/?TG=SEAL', CorpNum, UserID)
+        return result.url
+
     def attachFile(self, CorpNum, ItemCode, MgtKey, FilePath, UserID=None):
         """ 파일 첨부
             args
